@@ -9,9 +9,9 @@ class INode(ILocation, IFullMapping):
     """A node.
     """
     
-    uuid = Attribute(u"UUID of this node.")
+    uuid = Attribute(u"``uuid.UUID`` of this node.")
     
-    path = Attribute(u"Path of target element as list")
+    path = Attribute(u"Path of node as list")
     
     root = Attribute(u"Root node")
     
@@ -43,6 +43,10 @@ class INode(ILocation, IFullMapping):
         read node to move, delete it from tree and re-add it elsewhere.
         """
     
+    def detach(key):
+        """Detach child Node. needed for Node movement.
+        """
+    
     def printtree():
         """Debugging helper.
         """
\ No newline at end of file
